<?php
/**
 * This file handles the granular control of SEO for
 * the framework.
 *
 * It handles <title> tag generation, meta keywords/descriptions,
 * and the <link rel="canonical"> tag.
 *
 * If either HeadSpace2, All-in-One SEO Pack, or SEO Title Tag
 * are active, they will be given priority over the framework SEO.
 *
 * @package Genesis
 * @author Nathan Rice
 **/


/**
 * This next section adds a new box to the post/page edit screen,
 * so that the user can set SEO options on a per-post/page basis.
 *
 * genesis_add_inpost_seo_box() is used to register the boxes.
 * @uses add_meta_box
 * genesis_inpost_seo_box() generates the content in the boxes.
 * @uses wp_create_nonce, checked, genesis_get_custom_field
 *
 * @since 0.1.3
 */
add_action('admin_menu', 'genesis_add_inpost_seo_box');
function genesis_add_inpost_seo_box() {
	add_meta_box('genesis_inpost_seo_box', __('SEO Options and Settings', 'genesis'), 'genesis_inpost_seo_box', 'post', 'normal', 'high');
	add_meta_box('genesis_inpost_seo_box', __('SEO Options and Settings', 'genesis'), 'genesis_inpost_seo_box', 'page', 'normal', 'high');
}
function genesis_inpost_seo_box() { ?>
	
	<input type="hidden" name="genesis_inpost_seo_nonce" value="<?php echo wp_create_nonce(plugin_basename(__FILE__)); ?>" />
	
	<p><label for="genesis_title"><b>Custom Document Title</b> (<code>&lt;title&gt;</code> Tag):</label></p>
	<p><input style="width: 99%;" type="text" name="genesis_seo[_genesis_title]" id="genesis_title" value="<?php echo esc_attr( genesis_get_custom_field('_genesis_title')); ?>" /></p>
	
	<p><label for="genesis_description"><b>Custom Post/Page Meta Description</b> (<code>&lt;meta name="description"&gt;</code>):</label></p>
	<p><textarea style="width: 99%;" name="genesis_seo[_genesis_description]" id="genesis_description"><?php echo htmlspecialchars(genesis_get_custom_field('_genesis_description')); ?></textarea></p>
	
	<p><label for="genesis_keywords"><b>Custom Post/Page Meta Keywords</b> (<code>&lt;meta name="keywords"&gt;</code>, comma separated):</label></p>
	<p><input style="width: 99%;" type="text" name="genesis_seo[_genesis_keywords]" id="genesis_keywords" value="<?php echo esc_attr(genesis_get_custom_field('_genesis_keywords')); ?>" /></p>
	
	<br />
	
	<p><b>Noindex this Post/Page</b> ( <a href="http://www.robotstxt.org/meta.html" target="_blank">more info</a> )</p>
	<p><input type="checkbox" name="genesis_seo[_genesis_noindex]" id="genesis_noindex" value="1" <?php checked(1, genesis_get_custom_field('_genesis_noindex')); ?> /> 
	<label for="genesis_noindex">Apply <code>noindex</code> to this post/page?</label></p>
	
	<br />
	
	<p><b>Nofollow this Post/Page</b> ( <a href="http://www.robotstxt.org/meta.html" target="_blank">more info</a> )</p>
	<p><input type="checkbox" name="genesis_seo[_genesis_nofollow]" id="genesis_nofollow" value="1" <?php checked(1, genesis_get_custom_field('_genesis_nofollow')); ?> /> 
	<label for="genesis_nofollow">Apply <code>nofollow</code> to this post/page?</label></p>
	
<?php if(!genesis_get_seo_option('disable_canonical')) : ?>
	<br />
	<p><b>Remove canonical tag</b> ( <a href="http://www.mattcutts.com/blog/canonical-link-tag/" target="_blank">more info</a> )</p>
	<p><input type="checkbox" name="genesis_seo[_genesis_disable_canonical]" id="genesis_disable_canonical" value="1" <?php checked(1, genesis_get_custom_field('_genesis_disable_canonical')); ?> /> 
	<label for="genesis_disable_canonical">Disable the <code>&lt;link rel="canonical" /&gt;</code> tag for this post/page?</label>
<?php endif;
}

/**
 * This function saves the SEO settings when we save a post/page.
 * It does so by grabbing the array passed in $_POST, looping through
 * it, and saving each key/value pair as a custom field.
 *
 * @uses wp_verify_nonce, plugin_basename, current_user_can
 * @uses add_post_meta, update_post_meta, delete_post_meta, get_custom_field
 *
 * @since 0.1.3
 */
add_action('save_post', 'genesis_inpost_seo_save', 1, 2);
function genesis_inpost_seo_save($post_id, $post) {
	
	//	verify the nonce
	if (!wp_verify_nonce($_POST['genesis_inpost_seo_nonce'], plugin_basename(__FILE__)))
		return $post->ID;
		
	//	don't try to save the data under autosave, ajax, or future post.
	if(defined(DOING_AUTOSAVE) && DOING_AUTOSAVE) return;
	if(defined(DOING_AJAX) && DOING_AJAX) return;
	if(defined(DOING_CRON) && DOING_CRON) return;

	//	is the user allowed to edit the post or page?
	if(('page' == $_POST['post_type'] && !current_user_can('edit_page', $post->ID)) || !current_user_can('edit_post', $post->ID ))
		return $post->ID;
		
	$genesis_seo = $_POST['genesis_seo'];
		
	//	gotta set these manually, unfortunately, since they're checkboxes
	$genesis_seo['_genesis_noindex'] = $_POST['genesis_seo']['_genesis_noindex'];
	$genesis_seo['_genesis_nofollow'] = $_POST['genesis_seo']['_genesis_nofollow'];
	$genesis_seo['_genesis_disable_canonical'] = $_POST['genesis_seo']['_genesis_disable_canonical'];
	
	//	store the custom fields
	foreach ($genesis_seo as $key => $value) {
		if($post->post_type == 'revision') return; // don't try to store data during revision save
		
		//	sanitize the title, description, and tags before storage
		if($key == '_genesis_title' || $key == '_genesis_description' || $key == '_genesis_keywords')
			$value = esc_html(strip_tags($value));
		
		//	save/update
		if(!genesis_get_custom_field($key))
			update_post_meta($post->ID, $key, $value);
		else
			add_post_meta($post->ID, $key, $value, TRUE);
		
		//delete if blank
		if(!$value) delete_post_meta($post->ID, $key);
	}
}

/**
 * Disable all SEO functions if the All-in-One SEO Pack or Headspace is active
 *
 * @since 0.1.3
 */
if (class_exists('All_in_One_SEO_Pack') || class_exists('HeadSpace_Plugin')) {
	remove_filter('wp_title', 'genesis_default_title', 10, 3);
	remove_action('genesis_meta','genesis_seo_meta');
	remove_action('genesis_meta','genesis_index_follow_logic');
	remove_action('genesis_meta','genesis_canonical');
	remove_action('admin_menu', 'genesis_add_inpost_seo_box');
	remove_action('save_post', 'genesis_inpost_seo_save', 1, 2);
}

/**
 * disable Genesis <title> generation if SEO Title Tag is active
 *
 * @since 0.1.3
 */
if (function_exists('seo_title_tag')) {
	remove_filter('wp_title', 'genesis_default_title', 10, 3);
	remove_action('genesis_title', 'wp_title');
	add_action('genesis_title', 'seo_title_tag');
}
?>